@@ -86,17 +86,23 @@ void DepositFiles::checkUrlIsValid() {
     }
     else {
         QString response(reply->readAll());
-        QScriptEngine engine;
-        QString script = response.section("eval( ", 1, 1).section(");", 0, 0);
-        QString fileNameElement = engine.evaluate(script).toString();
 
-        if (fileNameElement.isEmpty()) {
-            emit urlChecked(false);
-        }
-        else {
-            QString fileName = fileNameElement.section("title=\"", 1, 1).section('"', 0, 0);
-            emit urlChecked(true, reply->request().url(), this->serviceName(), fileName);
-        }
+	if (response.contains("file does not exist")) {
+	    emit urlChecked(false);
+	}
+	else {
+            QScriptEngine engine;
+            QString script = response.section("eval( ", 1, 1).section(");", 0, 0);
+            QString fileNameElement = engine.evaluate(script).toString();
+
+            if (fileNameElement.isEmpty()) {
+                emit urlChecked(false);
+            }
+            else {
+                QString fileName = fileNameElement.section("title=\"", 1, 1).section('"', 0, 0);
+                emit urlChecked(true, reply->request().url(), this->serviceName(), fileName);
+            }
+	}
     }
 
     reply->deleteLater();
@@ -155,7 +161,12 @@ void DepositFiles::onWebPageDownloaded() {
             m_fileId = response.section("var fid = '", 1, 1).section('\'', 0, 0);
 
             if ((m_captchaKey.isEmpty()) || (m_fileId.isEmpty())) {
-                emit error(UrlError);
+		if (response.contains("file does not exist")) {
+                    emit error(NotFound);
+		}
+		else {
+		    emit error(UrlError);
+		}
             }
             else {
                 this->startWait(60000);
